Description
Creates colour gradient between two hexcodes.
Usage
cg(colour1, colour2, n = 15)
Value
A vector of hexcodes of length n, containing a colour gradient between colour =1 and colour2.
Arguments
- colour1
The first hexcode colour.
- colour2
The second hexcode colour.
- n
The length of the vector returned by the function.